# conceal
conceal is a python package for developing a digital/fractal camouflage image
> following in the footsteps of the article "Introducing the National Algorithim" by Sjef van Gaalen about the new camouflage patterns of The Netherlands (NFP), this package aims to create a digital/fractal camouflage based upon images of the environment and supplied required colors
## Installation
```
git clone https://github.com/michaelpeterswa/conceal.git
```
Or download the file manually.
## Release History
* 0.0.1
   * Opened Repository (08.18.2020)
## Meta
Michael Peters - *enter additional contact information here*

Distributed under the ____ license. See ``LICENSE`` for more information.